@@ -524,6 +524,7 @@ static void
 begin_write (AsyncData *async)
 {
 	GeditGioDocumentSaver *gvsaver;
+	gchar *buffer;
 	gsize len;
 	GError *error = NULL;
 
@@ -533,14 +534,13 @@ begin_write (AsyncData *async)
 	 * backup as of yet
 	 */
 	gvsaver = async->saver;
-	gchar *buffer = gedit_document_saver_get_document_contents (GEDIT_DOCUMENT_SAVER (gvsaver), &len, &error);
-	
-	if (buffer)
+	buffer = gedit_document_saver_get_document_contents (GEDIT_DOCUMENT_SAVER (gvsaver), &len, &error);
+	if (buffer != NULL && len > 0)
 	{
 		/* Append new line to buffer */
 		buffer = append_new_line (gvsaver, buffer, &len, &error);
 	}
-	
+
 	if (!buffer)
 	{
 		async_failed (async, error);
