@@ -29,14 +29,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-spinner.h,v 1.4 2006/10/19 15:56:44 pborelli Exp $
+ * $Id$
  */
 
 #ifndef __GEDIT_SPINNER_H__
 #define __GEDIT_SPINNER_H__
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkenums.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
