@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-time-plugin.c 6749 2008-12-29 13:41:23Z icq $
+ * $Id$
  */
 
 /*
@@ -719,7 +719,6 @@ get_format_from_list (GtkWidget *listview)
 	GtkTreeModel *model;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
-        gint selected_value;
 
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -731,12 +730,16 @@ get_format_from_list (GtkWidget *listview)
 
 	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
 	{
+	        gint selected_value;
+
 		gtk_tree_model_get (model, &iter, COLUMN_INDEX, &selected_value, -1);
+
+		gedit_debug_message (DEBUG_PLUGINS, "Sel value: %d", selected_value);
+
+	        return selected_value;
 	}
 
-	gedit_debug_message (DEBUG_PLUGINS, "Sel value: %d", selected_value);
-
-        return selected_value;
+	g_return_val_if_reached (0);
 }
 
 static TimeConfigureDialog *
@@ -773,14 +776,16 @@ get_configure_dialog (GeditTimePlugin *plugin)
 
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), 2); /* 2 * 5 + 2 = 12 */
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
+			     2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dialog->dialog))),
+					5);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dialog->dialog))), 6);
 
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
 	data_dir = gedit_plugin_get_data_dir (GEDIT_PLUGIN (plugin));
-	ui_file = g_build_filename (data_dir, "time.ui", NULL);
+	ui_file = g_build_filename (data_dir, "gedit-time-setup-dialog.ui", NULL);
 	ret = gedit_utils_get_ui_objects (ui_file,
 					  root_objects,
 					  &error_widget,
@@ -799,7 +804,7 @@ get_configure_dialog (GeditTimePlugin *plugin)
 
 	if (!ret)
 	{
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
+		gtk_box_pack_start_defaults (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
 					     error_widget);
 		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);
 
@@ -852,7 +857,7 @@ get_configure_dialog (GeditTimePlugin *plugin)
 	/* setup a window of a sane size. */
 	gtk_widget_set_size_request (GTK_WIDGET (viewport), 10, 200);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
 			    content, FALSE, FALSE, 0);
 	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
@@ -931,11 +936,15 @@ get_choose_format_dialog (GtkWindow                 *parent,
 	GtkWidget *error_widget;
 	gboolean ret;
 	gchar *sf, *cf;
+	GtkWindowGroup *wg = NULL;
+	
+	if (parent != NULL)
+		wg = gtk_window_get_group (parent);
 
 	dialog = g_new0 (ChooseFormatDialog, 1);
 
 	data_dir = gedit_plugin_get_data_dir (GEDIT_PLUGIN (plugin));
-	ui_file = g_build_filename (data_dir, "time.ui", NULL);
+	ui_file = g_build_filename (data_dir, "gedit-time-dialog.ui", NULL);
 	ret = gedit_utils_get_ui_objects (ui_file,
 					  NULL,
 					  &error_widget,
@@ -952,17 +961,39 @@ get_choose_format_dialog (GtkWindow                 *parent,
 
 	if (!ret)
 	{
-		const gchar *err_message;
+		GtkWidget *err_dialog;
 
-		err_message = gtk_label_get_label (GTK_LABEL (error_widget));
-		gedit_warning (parent, "%s", err_message);
+		err_dialog = gtk_dialog_new_with_buttons (NULL,
+			parent,
+			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+			NULL);
 
-		g_free (dialog);
-		gtk_widget_destroy (error_widget);
+		if (wg != NULL)
+			gtk_window_group_add_window (wg, GTK_WINDOW (err_dialog));
+
+		gtk_window_set_resizable (GTK_WINDOW (err_dialog), FALSE);
+		gtk_dialog_set_has_separator (GTK_DIALOG (err_dialog), FALSE);
+		gtk_dialog_set_default_response (GTK_DIALOG (err_dialog), GTK_RESPONSE_OK);
+
+		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (err_dialog))),
+				   error_widget);
+
+		g_signal_connect (G_OBJECT (err_dialog),
+				  "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_widget_show_all (err_dialog);
 
 		return NULL;
 	}
 
+	gtk_window_group_add_window (wg,
+			     	     GTK_WINDOW (dialog->dialog));
+	gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog), parent);
+	gtk_window_set_modal (GTK_WINDOW (dialog->dialog), TRUE);
+
 	sf = get_selected_format (plugin);
 	create_formats_list (dialog->list, sf, plugin);
 	g_free (sf);
@@ -1113,32 +1144,23 @@ time_cb (GtkAction  *action,
 	}
         else
         {
-        	GtkWindowGroup *wg;
 		ChooseFormatDialog *dialog;
 
 		dialog = get_choose_format_dialog (GTK_WINDOW (data->window),
 						   prompt_type,
 						   data->plugin);
-		g_return_if_fail (dialog != NULL);
+		if (dialog != NULL)
+		{
+			dialog->buffer = buffer;
+			dialog->plugin = data->plugin;
 
-		wg = gedit_window_get_group (data->window);
+			g_signal_connect (dialog->dialog,
+					  "response",
+					  G_CALLBACK (choose_format_dialog_response_cb),
+					  dialog);
 
-		gtk_window_group_add_window (wg,
-				     	     GTK_WINDOW (dialog->dialog));
-
-		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
-					      GTK_WINDOW (data->window));
-		gtk_window_set_modal (GTK_WINDOW (dialog->dialog), TRUE);
-
-		dialog->buffer = buffer;
-		dialog->plugin = data->plugin;
-
-		g_signal_connect (dialog->dialog,
-				  "response",
-				  G_CALLBACK (choose_format_dialog_response_cb),
-				  dialog);
-
-		gtk_widget_show (GTK_WIDGET (dialog->dialog));
+			gtk_widget_show (GTK_WIDGET (dialog->dialog));
+		}
 
 		return;
 	}
